@@ -161,7 +161,7 @@ def test_add_paragraph_with_custom_font3():
     with PDFDancer.open(pdf_path, token=token, base_url=base_url, timeout=30.0) as pdf:
         pdf.new_paragraph() \
             .text("Awesomely\nObvious!") \
-            .font_file(str(ttf_path), 24) \
+            .font_file(ttf_path, 24) \
             .line_spacing(1.8) \
             .color(Color(0, 0, 255)) \
             .at(0, 300.1, 500) \
